@@ -53,6 +53,9 @@ class KPUBLICTRANSPORT_EXPORT Manager : public QObject
     /** @see backendsEnabledByDefault() */
     Q_PROPERTY(bool backendsEnabledByDefault READ backendsEnabledByDefault WRITE setBackendsEnabledByDefault NOTIFY configurationChanged)
 
+    /** QML-compatible access to backends(). */
+    Q_PROPERTY(QVariantList backends READ backendsVariant CONSTANT)
+
 public:
     explicit Manager(QObject *parent = nullptr);
     ~Manager() override;
@@ -95,7 +98,7 @@ public:
     const std::vector<Backend>& backends() const;
 
     /** Returns whether the use of the backend with a given identifier is enabled. */
-    bool isBackendEnabled(const QString &backendId) const;
+    Q_INVOKABLE bool isBackendEnabled(const QString &backendId) const;
     /** Sets whether the backend with the given identifier should be used.
      *  @note If allowInsecureBackends() is @c false, this has precedence.
      */
@@ -134,6 +137,7 @@ Q_SIGNALS:
 
 private:
     Q_DECL_HIDDEN QVariantList attributionsVariant() const;
+    Q_DECL_HIDDEN QVariantList backendsVariant() const;
 
     std::unique_ptr<ManagerPrivate> d;
 };
